/*   This file is part of Xsltop.
*
*    Xsltop is free software: you can redistribute it and/or modify
*    it under the terms of the GNU General Public License as published by
*    the Free Software Foundation.
*
*    Xsltop is distributed in the hope that it will be useful,
*    but WITHOUT ANY WARRANTY; without even the implied warranty of
*    MERCHANTABILITY.  See the
*    GNU General Public License for more details.
*
*    See <http://www.gnu.org/licenses/>.
*/
package xsltop.util;

import javax.swing.JTextPane;
/** Just enum level messages. */
enum Level {
	DEBUG,
	INFO,
	ERROR
};

/**
 * Logger to display log in the console GUI.
 * 
 * @author philippe voncken
 */
public class FunctionalLogger {
	
	/** The level. */
	private Level level = Level.DEBUG;
	
	/** The console. */
	private JTextPane console;
	
	/**
	 * Instantiates a new functional logger.
	 * 
	 * @param out the out
	 */
	public FunctionalLogger(JTextPane out) {
		this.console = out;
	}
	
	/**
	 * Write message.
	 * 
	 * @param message the message
	 */
	private void writeMessage(String message) {
		console.setText(console.getText() + message + "\n");
	}
	
	/**
	 * Debug.
	 * 
	 * @param message the message
	 */
	public void debug(String message) {
		if (level.equals(Level.DEBUG)) {
			writeMessage("debug:" + message);
		}
	}
	
	/**
	 * Info.
	 * 
	 * @param message the message
	 */
	public void info(String message) {
		if (level.equals(Level.INFO)
				|| level.equals(Level.DEBUG)) {
			writeMessage("info :" + message);
		}
	}
	
	/**
	 * Error.
	 * 
	 * @param message the message
	 */
	public void error(String message) {
		if (level.equals(Level.ERROR)
				|| level.equals(Level.INFO)
				|| level.equals(Level.DEBUG)) {
			writeMessage("error:" + message);
		}
	}
	
	/**
	 * Sets the level to debug.
	 */
	public void setLevelToDebug() {
		this.level = Level.DEBUG;
	}
	
	/**
	 * Sets the level to info.
	 */
	public void setLevelToInfo() {
		this.level = Level.INFO;
	}
	
	/**
	 * Sets the level to error.
	 */
	public void setLevelToError() {
		this.level = Level.ERROR;
	}
}
